package com.dragon.tj.portal.controller;

import com.dragon.tj.portal.auth.model.LoginUser;
import com.dragon.tj.portal.auth.util.SecurityUtils;
import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.entity.IssueInfo;
import com.dragon.tj.portal.entity.PageParam;
import com.dragon.tj.portal.service.IssueService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;

@RestController
@RequestMapping("/issue")
@EnableScheduling
public class IssueController {


    @Autowired
    private IssueService issueService;

    /*
     *   CRUD
     * */

    @PostMapping("add")
    public R addIssue(@RequestBody IssueInfo issueInfo) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        int b = issueService.addIssue(issueInfo, loginUser);
        if (b == 0){
            return R.failed("添加失败!!!");
        }

        return R.ok(b);
    }


    @GetMapping("delete/{id}")
    public R deleteIssue(@PathVariable("id") Long id) {
        return R.ok(issueService.deleteIssue(id));
    }


    @PostMapping("update")
    public R updateIssue(@RequestBody IssueInfo issueInfo) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        issueInfo.setAnswerUser(loginUser.getUsername());
        issueInfo.setUpdateTime(LocalDateTime.now());

        return R.ok(issueService.updateIssue(issueInfo));
    }


    @GetMapping("info/{id}")
    public R detail(@PathVariable("id") Long id) {
        return R.ok(issueService.detail(id));
    }

    /*
     *   通过标题,内容搜索
     * */
    @PostMapping("search")
    public R search(@RequestBody PageParam<IssueInfo> issueInfoPage) {

        return R.ok(issueService.search(issueInfoPage));
    }

}

